Spectral Operations
===================

Operations operating in the spectral domain, such as the Power Spectrum, Spetral Loss and the Potential.

.. automodapi:: cosmax.spectral_ops
   :no-inheritance-diagram: